@@ -408,7 +408,11 @@ struct fxt_trace_user_raw64 {
 
 #elif defined(__sparc__) || defined(__sparc)
 #  define FXT_RECORD_ARCH FXT_ARCH_SPARC
-#define FXT_ARCH_32
+#  ifdef __arch64__
+#    define FXT_ARCH_64
+#  else
+#    define FXT_ARCH_32
+#  endif
 
 #elif defined(__sh__)
 #  define FXT_RECORD_ARCH FXT_ARCH_SH
@@ -422,6 +426,14 @@ struct fxt_trace_user_raw64 {
 #  else
 #    error Unable to find a supported host architecture
 #  endif
+
+#  if __WORDSIZE == 32
+#    define FXT_ARCH_32
+#  elif __WORDSIZE == 64
+#    define FXT_ARCH_64
+#  else
+#    error Unable to find architecture word size
+#  endif
 #endif
 
 #ifdef FXT_ARCH_32
